@@ -32,7 +32,7 @@
 
 class UserConfigDialog : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 public:
 	UserConfigDialog(LDAPUserInfo user, LDAPConfig* parent = 0, const char* name = 0);
